==> dolphin-17.12.2.tar.xz: dolphin-17.12.2/src/settings/kcm/kcmdolphinnavigation.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Peter Penz <peter.penz19@gmail.com>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
 ***************************************************************************/

#ifndef KCMDOLPHINNAVIGATION_H
#define KCMDOLPHINNAVIGATION_H

#include <kcmodule.h>

class NavigationSettingsPage;

/**
 * @brief Allow to configure the Dolphin navigation.
 */
class DolphinNavigationConfigModule : public KCModule
{
    Q_OBJECT

public:
    DolphinNavigationConfigModule(QWidget* parent, const QVariantList& args);
    virtual ~DolphinNavigationConfigModule();

    virtual void save() Q_DECL_OVERRIDE;
    virtual void defaults() Q_DECL_OVERRIDE;

private:
    NavigationSettingsPage* m_navigation;
};

#endif

==> dolphin-20.03.90.tar.xz: dolphin-20.03.90/src/settings/kcm/kcmdolphinnavigation.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Peter Penz <peter.penz19@gmail.com>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
 ***************************************************************************/

#ifndef KCMDOLPHINNAVIGATION_H
#define KCMDOLPHINNAVIGATION_H

#include <kcmodule.h>

class NavigationSettingsPage;

/**
 * @brief Allow to configure the Dolphin navigation.
 */
class DolphinNavigationConfigModule : public KCModule
{
    Q_OBJECT

public:
    DolphinNavigationConfigModule(QWidget* parent, const QVariantList& args);
    ~DolphinNavigationConfigModule() override;

    void save() override;
    void defaults() override;

private:
    NavigationSettingsPage* m_navigation;
};

#endif
